use sqlx::{FromRow, PgPool};
use sqlx::types::chrono::{self, DateTime};
use crate::db_result::CountResult;

#[derive(Debug, Clone, FromRow, serde::Serialize)]
#[table_name = "feedback"]
pub struct Feedback {
    pub id: u64,
    pub user_id: u64,
    pub content: String,
    pub created_at: DateTime<chrono::Utc>,
}

impl Feedback {
    pub async fn search_feedback(page: u64, page_size: u64, db_pool: &PgPool) -> Result<Vec<Feedback>, sqlx::Error> {
        sqlx::query_as!(
            Feedback,
            r#"select id, user_id, content, created_at from feedback limit ? offset ?"#,
            page_size, page
        ).fetch_all(db_pool).await
    }

    pub async fn count_feedback(db_pool: &PgPool) -> Result<CountResult, sqlx::Error> {
        sqlx::query_as!(
            CountResult,
            r#"select count(*) from feedback"#,
        ).fetch_one(db_pool).await
    }

    pub async fn add_feedback(feedback: &mut Feedback, db_pool: &PgPool) -> Result<Feedback, sqlx::Error> {
        feedback.created_at = DateTime::default().to_utc();
        sqlx::query_as!(
            Feedback,
            r#"insert into feedback
            (user_id, content, created_at)
            values
            (?, ?, ?) returning *
            "#,
            feedback.user_id,
            feedback.content,
            feedback.created_at
        ).execute(db_pool)
    }
}