use sqlx::{FromRow, PgPool, QueryBuilder};
use sqlx::types::chrono::{self, DateTime};
use library::db;

#[derive(Debug, Clone, FromRow, serde::Serialize)]
#[table_name = "player_info"]
pub struct PlayerInfo {
    pub id: Option<u64>,
    pub username: String,
    pub email: String,
    pub platform_id: String,
    pub user_type: String,
    pub country_code: String,
    pub created_at: DateTime<chrono::Utc>,
}

impl PlayerInfo {
    pub async fn find_by_platform_id(platform_id: &str, db_pool: &PgPool) -> Result<PlayerInfo, sqlx::Error> {
        sqlx::query_as!(
            PlayerInfo,
            r#"select * from player_info where platform_id = ?"#,
            platform_id
        )
            .fetch_one(db_pool)
            .await
    }

    pub async fn add_player_info(player_info: &mut PlayerInfo, db_pool: &PgPool) -> Result<PlayerInfo, sqlx::Error> {
        player_info.created_at = DateTime::default().to_utc();
        sqlx::query_as!(
            PlayerInfo,
            r#"
            insert into player_info
            (username, email, platform_id, user_type, country_code, created_at)
            values
            (?, ?, ?, ?, ?, ?) returning *"#,
            player_info.username,
            player_info.email,
            player_info.platform_id,
            player_info.user_type,
            player_info.country_code,
            player_info.created_at,
        ).execute(db_pool)
    }
}